#ifndef _SYS_TIMEX_H_
#define _SYS_TIMEX_H_


#ifdef __cplusplus
extern "C" {
#endif





#ifdef __cplusplus
}
#endif
#endif
